# demo-py

Collecting tools I use to demo in one place.

![Python package](https://github.com/omars-lab/demo-py/workflows/Python%20package/badge.svg)

# Todo
- [ ] Add more charts
- [ ] Add an interactive time bar

# Personal Reminders
- To publish to pypi w/o an alpha version, push a commit with `Publish To PYPI` in its commit message.
